use super::{Error, ErrorString};
use std::path::PathBuf;
mod xml;

pub struct Configuration {
    pub publisher:    Option<String>,
    pub license_path: Option<PathBuf>,
    pub root:         Directory,
}

impl Configuration {
    pub fn new() -> Configuration {
        Configuration{publisher: None, license_path: None, root: Directory::new("root")}
    }
}

pub struct File {
    pub name:      String,
    pub path:      PathBuf,
    pub is_hidden: bool,
}

impl File {
    pub fn new() -> File {
        File{name: String::new(), path: PathBuf::new(), is_hidden: false}
    }
}

pub struct Directory {
    pub name:   String,
        member: Vec<DirMember>,
}

impl Directory {
    pub fn new(name: &str) -> Directory {
        Directory{name: String::from(name), member: Vec::new()}
    }

    pub fn add_file(&mut self, file: File) {
        self.member.push(DirMember::File(file));
    }

    pub fn add_dir(&mut self, dir: Directory) {
        self.member.push(DirMember::Directory(dir));
    }

    pub fn into_iter(self) -> std::vec::IntoIter<DirMember> {
        self.member.into_iter()
    }
}

pub enum DirMember {
    File(File),
    Directory(Directory),
} 

pub fn parse_xml(xml: String) -> Result<Configuration, Error> {
    Ok(xml::parse(xml)?)
}